summaryrefslogtreecommitdiffstats
path: root/g4f/Provider/Blackbox.py
diff options
context:
space:
mode:
authorTekky <98614666+xtekky@users.noreply.github.com>2024-10-30 09:54:54 +0100
committerGitHub <noreply@github.com>2024-10-30 09:54:54 +0100
commit1c8061af5550a150b1319d04275771698b226cec (patch)
tree489d5d84e812bd9ba3e2c88c2322b45f016c766d /g4f/Provider/Blackbox.py
parentre-include`AsyncClient` for backwards compatibility, with deprecationwarning. Use `Client` instead (diff)
parentUpdate (docs/async_client.md docs/client.md docs/interference-api.md g4f/client/client.py) (diff)
downloadgpt4free-1c8061af5550a150b1319d04275771698b226cec.tar
gpt4free-1c8061af5550a150b1319d04275771698b226cec.tar.gz
gpt4free-1c8061af5550a150b1319d04275771698b226cec.tar.bz2
gpt4free-1c8061af5550a150b1319d04275771698b226cec.tar.lz
gpt4free-1c8061af5550a150b1319d04275771698b226cec.tar.xz
gpt4free-1c8061af5550a150b1319d04275771698b226cec.tar.zst
gpt4free-1c8061af5550a150b1319d04275771698b226cec.zip
Diffstat (limited to '')
-rw-r--r--g4f/Provider/Blackbox.py10
1 files changed, 4 insertions, 6 deletions
diff --git a/g4f/Provider/Blackbox.py b/g4f/Provider/Blackbox.py
index 5cd43eed..4052893a 100644
--- a/g4f/Provider/Blackbox.py
+++ b/g4f/Provider/Blackbox.py
@@ -51,7 +51,6 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
'ReactAgent',
'XcodeAgent',
'AngularJSAgent',
- 'RepoMap',
]
agentMode = {
@@ -78,7 +77,6 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
'ReactAgent': {'mode': True, 'id': "React Agent"},
'XcodeAgent': {'mode': True, 'id': "Xcode Agent"},
'AngularJSAgent': {'mode': True, 'id': "AngularJS Agent"},
- 'RepoMap': {'mode': True, 'id': "repomap"},
}
userSelectedModel = {
@@ -174,7 +172,7 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
proxy: Optional[str] = None,
image: ImageType = None,
image_name: str = None,
- websearch: bool = False,
+ web_search: bool = False,
**kwargs
) -> AsyncGenerator[Union[str, ImageResponse], None]:
"""
@@ -186,7 +184,7 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
proxy (Optional[str]): Proxy URL, if needed.
image (ImageType): Image data to be processed, if any.
image_name (str): Name of the image file, if an image is provided.
websearch (bool): Enables or disables web search mode.
**kwargs: Additional keyword arguments.
Yields:
@@ -276,7 +274,7 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
"clickedForceWebSearch": False,
"visitFromDelta": False,
"mobileClient": False,
- "webSearchMode": websearch,
+ "webSearchMode": web_search,
"userSelectedModel": cls.userSelectedModel.get(model, model)
}
@@ -313,7 +311,7 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
else:
yield cleaned_response
else:
- if websearch:
+ if web_search:
match = re.search(r'\$~~~\$(.*?)\$~~~\$', cleaned_response, re.DOTALL)
if match:
source_part = match.group(1).strip()
@@ -186,7 +184,7 @@ class Blackbox(AsyncGeneratorProvider, ProviderModelMixin):
image (ImageType): Image data to be processed, if any.
image_name (str): Name of the image file, if an image is provided.
- websearch (bool): Enables or disables web search mode.
+ web_search (bool): Enables or disables web search mode.
**kwargs: Additional keyword arguments.
Yields: